@@ -615,11 +615,21 @@ gda_data_model_iter_move_to_row (GdaDataModelIter *iter, gint row)
 		gboolean move_ok;
 		model = iter->priv->data_model;
 		if (GDA_DATA_MODEL_GET_CLASS (model)->i_iter_at_row)
-			return (GDA_DATA_MODEL_GET_CLASS (model)->i_iter_at_row) (model, iter, row);
+			move_ok = (GDA_DATA_MODEL_GET_CLASS (model)->i_iter_at_row) (model, iter, row);
 		else {
 			/* default method */
-			return gda_data_model_iter_move_to_row_default (model, iter, row);
+			move_ok = gda_data_model_iter_move_to_row_default (model, iter, row);
 		}
+		
+		if (null_oks) {
+			gint i;
+			GSList *list;
+			for (i = 0, list = GDA_SET (iter)->holders; list; i++, list = list->next)
+				gda_holder_set_not_null ((GdaHolder*) list->data, null_oks[i]);
+			g_free (null_oks);
+		}
+		
+		return move_ok;
 	}
 }
 
@@ -885,7 +895,8 @@ gda_data_model_iter_get_row (GdaDataModelIter *iter)
  *
  * Declare all the parameters in @iter invalid, without modifying the
  * #GdaDataModel @iter is for or changing the row it represents. This method
- * is for internal usage.
+ * is for internal usage. Note that for gda_data_model_iter_is_valid() to return %FALSE,
+ * it is also necessary to set the "current-row" property to -1.
  */
 void
 gda_data_model_iter_invalidate_contents (GdaDataModelIter *iter)
@@ -954,7 +965,7 @@ gda_data_model_iter_get_holder_for_field (GdaDataModelIter *iter, gint col)
 	g_return_val_if_fail (GDA_IS_DATA_MODEL_ITER (iter), NULL);
 	g_return_val_if_fail (iter->priv, NULL);
 
-	return g_slist_nth_data (((GdaSet *) iter)->holders, col);
+	return gda_set_get_nth_holder ((GdaSet *) iter, col);
 }
 
 /**
